Index: gpu/command_buffer/client/gles2_implementation.h |
diff --git a/gpu/command_buffer/client/gles2_implementation.h b/gpu/command_buffer/client/gles2_implementation.h |
index 7d17d64a46221579dba7a359404066443d103831..25021fbeb32d842f4b2a5d411b63ac3d71928a47 100644 |
--- a/gpu/command_buffer/client/gles2_implementation.h |
+++ b/gpu/command_buffer/client/gles2_implementation.h |
@@ -510,13 +510,19 @@ class GLES2_IMPL_EXPORT GLES2Implementation |
void RestoreElementAndArrayBuffers(bool restore); |
void RestoreArrayBuffer(bool restrore); |
// The pixels pointer should already account for unpack skip rows and skip |
// pixels. |
void TexSubImage2DImpl( |
GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, |
GLsizei height, GLenum format, GLenum type, uint32 unpadded_row_size, |
const void* pixels, uint32 pixels_padded_row_size, GLboolean internal, |
ScopedTransferBufferPtr* buffer, uint32 buffer_padded_row_size); |
+ void TexSubImage3DImpl( |
+ GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, |
+ GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, |
+ uint32 unpadded_row_size, const void* pixels, |
+ uint32 pixels_padded_row_size, GLboolean internal, |
+ ScopedTransferBufferPtr* buffer, uint32 buffer_padded_row_size); |
// Helpers for query functions. |
bool GetHelper(GLenum pname, GLint* params); |
@@ -640,12 +646,18 @@ class GLES2_IMPL_EXPORT GLES2Implementation |
// unpack row length as last set by glPixelStorei |
GLint unpack_row_length_; |
+ // unpack image height as last set by glPixelStorei |
+ GLint unpack_image_height_; |
+ |
// unpack skip rows as last set by glPixelStorei |
GLint unpack_skip_rows_; |
// unpack skip pixels as last set by glPixelStorei |
GLint unpack_skip_pixels_; |
+ // unpack skip images as last set by glPixelStorei |
+ GLint unpack_skip_images_; |
+ |
// pack reverse row order as last set by glPixelstorei |
bool pack_reverse_row_order_; |
@@ -731,8 +743,7 @@ class GLES2_IMPL_EXPORT GLES2Implementation |
GLES2ImplementationErrorMessageCallback* error_message_callback_; |
- scoped_ptr<std::string> current_trace_category_; |
- scoped_ptr<std::string> current_trace_name_; |
+ int current_trace_stack_; |
GpuControl* gpu_control_; |
@@ -510,13 +510,19 @@ class GLES2_IMPL_EXPORT GLES2Implementation |
void RestoreElementAndArrayBuffers(bool restore); |
void RestoreArrayBuffer(bool restrore); |
- // The pixels pointer should already account for unpack skip rows and skip |
- // pixels. |
+ // The pixels pointer should already account for unpack skip |
+ // images/rows/pixels. |
void TexSubImage2DImpl( |
GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, |